==> com.liferay.headless.commerce.admin.shipment.impl-1.0.12-sources.jar: com/liferay/headless/commerce/admin/shipment/internal/jaxrs/exception/mapper/ShipmentInactiveWarehouseExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.commerce.admin.shipment.internal.jaxrs.exception.mapper;

import com.liferay.commerce.exception.CommerceShipmentInactiveWarehouseException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * @author Andrea Sbarra
 */
@Component(
	enabled = false,
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Shipment)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Shipment.ShipmentInactiveWarehouseException"
	},
	service = ExceptionMapper.class
)
public class ShipmentInactiveWarehouseExceptionMapper
	extends BaseExceptionMapper<CommerceShipmentInactiveWarehouseException> {

	@Override
	protected Problem getProblem(
		CommerceShipmentInactiveWarehouseException
			commerceShipmentInactiveWarehouseException) {

		return new Problem(
			Response.Status.BAD_REQUEST,
			commerceShipmentInactiveWarehouseException.getMessage());
	}

}

==> com.liferay.headless.commerce.admin.shipment.impl-1.0.36-sources.jar: com/liferay/headless/commerce/admin/shipment/internal/jaxrs/exception/mapper/ShipmentInactiveWarehouseExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.commerce.admin.shipment.internal.jaxrs.exception.mapper;

import com.liferay.commerce.exception.CommerceShipmentInactiveWarehouseException;
import com.liferay.headless.commerce.core.exception.mapper.BaseExceptionMapper;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * @author Andrea Sbarra
 * @author Alessio Antonio Rendina
 */
@Component(
	enabled = false,
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Shipment)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Commerce.Admin.Shipment.ShipmentInactiveWarehouseExceptionMapper"
	},
	service = ExceptionMapper.class
)
public class ShipmentInactiveWarehouseExceptionMapper
	extends BaseExceptionMapper<CommerceShipmentInactiveWarehouseException> {

	@Override
	public String getErrorDescription() {
		return "Inactive warehouse";
	}

	@Override
	public Response.Status getStatus() {
		return Response.Status.BAD_REQUEST;
	}

}
